@@ -4,12 +4,13 @@ from cleo import Application
 from . import HomeServerSetup
 
 
-class GreetCommand(Command):
-    """
-    Installs bacchus.
-    Requires:
-        - Valid DNS hostname registered in a supported provider
-        - NAT or direct exposure of the given machine's openvpn port (1194)
+class MainCommand(Command):
+    """Installs bacchus.
+
+    Requires
+
+    - Valid DNS hostname registered in a supported provider
+    - NAT or direct exposure of the given machine's openvpn port (1194)
 
     install
         {dns-domain? : Domain (FQDN) for virtualhosts}
@@ -21,7 +22,7 @@ class GreetCommand(Command):
     """
     def handle(self):
         """Handle command"""
-        setup = HomeServerSetup(domain=self.argument('domain'),
+        setup = HomeServerSetup(domain=self.argument('dns-domain'),
                                 nextcloud_username=self.argument('username'),
                                 nextcloud_password=self.argument('password'),
                                 iface=self.argument('iface'),
@@ -32,5 +33,5 @@ class GreetCommand(Command):
 
 def main():
     application = Application()
-    application.add(GreetCommand())
+    application.add(MainCommand())
     application.run()
